@@ -21,7 +21,7 @@ from ..models.status import (
 from os import getenv
 
 logger = getLogger(__name__)
-raw_logger = getLogger("bittrade_cryptodotcom_websocket.connection.generic.raw")
+raw_logger = getLogger("bittrade_cryptodotcom_websocket.raw_socket.received")
 
 USER_URL = getenv("CRYPTODOTCOM_USER_URL", "wss://stream.crypto.com/exchange/v1/user")
 MARKET_URL = getenv(
@@ -64,7 +64,7 @@ def raw_websocket_connection(
             def on_message(ws: WebSocketApp, message: bytes | str):
                 pass_message = orjson.loads(message)
                 category = WEBSOCKET_MESSAGE
-                raw_logger.debug("--> %s", message)
+                raw_logger.debug(message)
                 if pass_message.get("method") == "public/heartbeat":
                     category = WEBSOCKET_HEARTBEAT
                     # We need to respond or we'll lose connection
