@@ -1,6 +1,5 @@
 from typing import Callable
 from reactivex import Observable, operators
-import multiprocessing
 
 from logging import getLogger
 from typing import Callable, Optional, cast, TYPE_CHECKING
@@ -65,8 +64,7 @@ def get_framework(
     exchange = cryptocom()
     if load_markets:
         exchange.load_markets()
-    optimal_thread_count = multiprocessing.cpu_count()
-    pool_scheduler = ThreadPoolScheduler(optimal_thread_count)
+    pool_scheduler = ThreadPoolScheduler(200)
     all_subscriptions = CompositeDisposable()
     # Set up sockets
     public_sockets = public_websocket_connection()
