@@ -9,6 +9,7 @@ from .book import (
     RawOrderbookEntry,
     OrderbookEntryNamedTuple,
     OrderbookDict,
+    TopPrices,
 )
 from .framework import BookConfig, CryptodotcomContext
 from .status import Status
@@ -34,6 +35,7 @@ __all__ = [
     "RawOrderbook",
     "RawOrderbookEntry",
     "Status",
+    "TopPrices",
     "Trade",
     "UserBalance",
     "WebsocketBundle",
