@@ -7,6 +7,7 @@ from .get_positions import get_positions_factory
 from .get_deposit_address import get_deposit_address_factory
 from .close_position import close_position_factory, close_position_http_factory
 from .user_get_trades import get_user_trades_http, get_user_trades_factory
+from .get_book import get_book_http, map_to_raw_orderbook, map_top_prices
 
 
 __all__ = [
@@ -16,11 +17,14 @@ __all__ = [
     "close_position_factory",
     "close_position_http_factory",
     "create_order_factory",
+    "get_book_http",
     "get_deposit_address_factory",
     "get_positions_factory",
     "get_user_balance_factory",
     "get_user_open_orders_factory",
     "get_user_trades_http",
     "get_user_trades_factory",
+    "map_top_prices",
+    "map_to_raw_orderbook",
     "user_balance_for_instrument",
 ]
