@@ -1,4 +1,5 @@
-from typing import Any, Callable, Optional
+import dataclasses
+from typing import Any, Callable, Optional, TYPE_CHECKING
 from ..connection import wait_for_response
 from ..models import (
     CryptodotcomResponseMessage,
@@ -11,15 +12,18 @@ from reactivex import Observable, operators, disposable, just, throw
 from ..events import MethodName
 from ccxt import cryptocom
 from reactivex.scheduler import NewThreadScheduler
+from ..models.rest import OrderCreateRequest
 
+if TYPE_CHECKING:
+    from ..models.order import OrderDict
 
 def order_confirmation(
     messages: Observable[CryptodotcomResponseMessage],
-    exchange: cryptocom,
     order_id: str,
 ):
     def is_match(message: CryptodotcomResponseMessage) -> bool:
         try:
+            # TODO we should probably not assume single order per message for the future
             return message.result["data"][0]["order_id"] == order_id
         except:
             return False
@@ -27,9 +31,9 @@ def order_confirmation(
     return messages.pipe(
         operators.filter(is_match),
         operators.take(1),
-        operators.map(lambda x: (exchange.parse_order(x.result["data"][0]))),
+        operators.map(lambda x: x.result["data"][0]), 
         operators.flat_map(
-            lambda x: just(x) if x["status"] == "open" else throw(x["status"])
+            lambda x: just(x) if x["status"] in ["ACTIVE", "FILLED"] else throw(x["status"])
         ),
         operators.timeout(4.0),
     )
@@ -40,7 +44,7 @@ def create_order_factory(
     exchange: cryptocom,
     socket: EnhancedWebsocketBehaviorSubject,
 ) -> Callable[
-    [str, str, str, float, Optional[float], Optional[Any]], Observable[dict[str, Any]]
+    [OrderCreateRequest], Observable["OrderDict"]
 ]:
     """Factory for create order API call
 
@@ -50,23 +54,11 @@ def create_order_factory(
         socket (EnhancedWebsocketBehaviorSubject): Socket behavior subject
 
     Returns:
-        Callable[ [str, str, str, float, Optional[float], Optional[Any]], Observable[dict[str, Any]] ]: Arguments for the returned function are:
-
-        symbol: str,
-        type: str,
-        side: str,
-        amount: float,
-        price: Optional[float]=None,
-        params=None,
+        Callable[ [OrderCreateRequest], Observable[OrderDict] ]: Arguments for the returned function are:
     """
 
     def create_order(
-        symbol: str,
-        type: str,
-        side: str,
-        amount: float,
-        price: Optional[float] = None,
-        params: Optional[dict[str, Any]] = None,
+        order_details: OrderCreateRequest
     ):
         """Create order
 
@@ -81,18 +73,19 @@ def create_order_factory(
         Returns:
             dict: Order per CCXT style
         """
-        params = params or {}
-        market = exchange.market(symbol)
-        uppercaseType = type.upper()
+        params = order_details.params or {}
+        market = exchange.market(order_details.symbol)
+        uppercaseType = order_details.type.upper()
         instrument_name = market["id"]
+        symbol, amount, price = order_details.symbol, order_details.amount, order_details.price
         request = {
             "instrument_name": instrument_name,
-            "side": side.upper(),
+            "side": order_details.side.upper(),
             "type": uppercaseType,
             "quantity": exchange.amount_to_precision(symbol, amount),
         }
-        if params.get("client_oid"):
-            request["client_oid"] = params["client_oid"]
+        client_order_id = order_details.client_order_id
+        request["client_oid"] = client_order_id
         if (uppercaseType == "LIMIT") or (uppercaseType == "STOP_LIMIT"):
             request["price"] = exchange.price_to_precision(symbol, price)
         postOnly = exchange.safe_value(params, "postOnly", False)
@@ -100,25 +93,29 @@ def create_order_factory(
             request["exec_inst"] = "POST_ONLY"
 
         def subscribe(observer, scheduler=None):
+            scheduler = NewThreadScheduler()
             recorded_messages = messages.pipe(
                 operators.filter(
                     lambda x: (
                         x.result.get("channel") == f"user.order.{instrument_name}"
                     )
                 ),
-                debug_operator(
-                    f"Recorded messages for {params.get('client_oid')}", __name__
-                ),
                 operators.replay(),
             )
-            sub = recorded_messages.connect(scheduler=NewThreadScheduler())
             message_id, sender = socket.value.request_to_observable(
                 CryptodotcomRequestMessage(MethodName.CREATE_ORDER, params=request)
             )
+            answer_messages = messages.pipe(
+                operators.filter(lambda x: x.method == MethodName.CREATE_ORDER.value),
+                operators.replay()
+            )
+            answer_sub = answer_messages.connect(scheduler=scheduler)
+            feed_sub = recorded_messages.connect(scheduler=scheduler)
 
             return disposable.CompositeDisposable(
-                sub,
-                messages.pipe(
+                answer_sub,
+                feed_sub,
+                answer_messages.pipe(
                     wait_for_response(
                         message_id,
                         sender,
@@ -129,7 +126,7 @@ def create_order_factory(
                     ),
                     operators.flat_map(
                         lambda x: order_confirmation(
-                            recorded_messages, exchange, x["order_id"]
+                            recorded_messages, x["order_id"]
                         )
                     ),
                 ).subscribe(observer, scheduler=scheduler),
